Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ContainerMessage ¶
type ContainerMessage struct {
// contains filtered or unexported fields
}
ContainerMessage is a message coming from a container Source
func NewContainerMessage ¶
func NewContainerMessage(content []byte) *ContainerMessage
NewContainerMessage returns a new ContainerMessage
func (ContainerMessage) Content ¶
func (m ContainerMessage) Content() []byte
Content returns the content the message, the actual log line
func (ContainerMessage) GetOrigin ¶
func (m ContainerMessage) GetOrigin() *Origin
GetOrigin returns the Origin from which the message comes
func (ContainerMessage) GetSeverity ¶
func (m ContainerMessage) GetSeverity() []byte
GetSeverity returns the severity of the message when set
func (ContainerMessage) SetContent ¶
func (m ContainerMessage) SetContent(content []byte)
SetContent updates the content the message
func (ContainerMessage) SetOrigin ¶
func (m ContainerMessage) SetOrigin(Origin *Origin)
SetOrigin sets the integration from which the message comes
func (ContainerMessage) SetSeverity ¶
func (m ContainerMessage) SetSeverity(severity []byte)
SetSeverity sets the severity of the message
type FileMessage ¶
type FileMessage struct {
// contains filtered or unexported fields
}
FileMessage is a message coming from a File
func NewFileMessage ¶
func NewFileMessage(content []byte) *FileMessage
NewFileMessage returns a new FileMessage
func (FileMessage) Content ¶
func (m FileMessage) Content() []byte
Content returns the content the message, the actual log line
func (FileMessage) GetOrigin ¶
func (m FileMessage) GetOrigin() *Origin
GetOrigin returns the Origin from which the message comes
func (FileMessage) GetSeverity ¶
func (m FileMessage) GetSeverity() []byte
GetSeverity returns the severity of the message when set
func (FileMessage) SetContent ¶
func (m FileMessage) SetContent(content []byte)
SetContent updates the content the message
func (FileMessage) SetOrigin ¶
func (m FileMessage) SetOrigin(Origin *Origin)
SetOrigin sets the integration from which the message comes
func (FileMessage) SetSeverity ¶
func (m FileMessage) SetSeverity(severity []byte)
SetSeverity sets the severity of the message
type Message ¶
type Message interface {
Content() []byte
SetContent([]byte)
GetOrigin() *Origin
SetOrigin(*Origin)
GetSeverity() []byte
SetSeverity([]byte)
}
Message represents a log line sent to datadog, with its metadata
type NetworkMessage ¶
type NetworkMessage struct {
// contains filtered or unexported fields
}
NetworkMessage is a message coming from a network Source
func NewNetworkMessage ¶
func NewNetworkMessage(content []byte) *NetworkMessage
NewNetworkMessage returns a new NetworkMessage
func (NetworkMessage) Content ¶
func (m NetworkMessage) Content() []byte
Content returns the content the message, the actual log line
func (NetworkMessage) GetOrigin ¶
func (m NetworkMessage) GetOrigin() *Origin
GetOrigin returns the Origin from which the message comes
func (NetworkMessage) GetSeverity ¶
func (m NetworkMessage) GetSeverity() []byte
GetSeverity returns the severity of the message when set
func (NetworkMessage) SetContent ¶
func (m NetworkMessage) SetContent(content []byte)
SetContent updates the content the message
func (NetworkMessage) SetOrigin ¶
func (m NetworkMessage) SetOrigin(Origin *Origin)
SetOrigin sets the integration from which the message comes
func (NetworkMessage) SetSeverity ¶
func (m NetworkMessage) SetSeverity(severity []byte)
SetSeverity sets the severity of the message
type Origin ¶
type Origin struct {
Identifier string
LogSource *config.LogSource
Offset int64
Timestamp string
// contains filtered or unexported fields
}
Origin represents the Origin of a message
func (*Origin) TagsPayload ¶
TagsPayload returns the raw tag payload of the origin.